@@ -26,7 +26,7 @@ from collections import defaultdict, OrderedDict
 # pylint: disable=import-error
 # pylint: disable=import-error
 from hotdoc.core.exceptions import HotdocException
-from hotdoc.core.symbols import Symbol
+from hotdoc.core.symbols import Symbol, ProxySymbol
 from hotdoc.utils.signals import Signal
 from hotdoc.utils.loggable import debug, warn, Logger
 
@@ -44,15 +44,6 @@ Logger.register_warning_code(
 # pylint: disable=too-few-public-methods
 
 
-class ProxySymbol(Symbol):
-    """A proxy type to handle aliased symbols"""
-    __tablename__ = 'proxy_symbols'
-
-    def __init__(self, **kwargs):
-        self.target = None
-        Symbol.__init__(self, **kwargs)
-
-
 def serialize(obj):
     try:
         return obj.__getstate__()
@@ -130,10 +121,12 @@ class Database:
             return None
 
         aliases = kwargs.pop('aliases', [])
+        alias_symbols = []
         for alias in aliases:
-            self.create_symbol(ProxySymbol,
-                               unique_name=alias,
-                               target=unique_name)
+            alias_symbols.append(
+                self.create_symbol(ProxySymbol,
+                unique_name=alias,
+                target=unique_name))
 
         symbol = type_()
         debug('Created symbol with unique name %s' % unique_name,
@@ -141,6 +134,7 @@ class Database:
 
         for key, value in list(kwargs.items()):
             setattr(symbol, key, value)
+        symbol.aliases += alias_symbols
 
         self.__symbols[unique_name] = symbol
         self.__aliases[unique_name].extend(aliases)
@@ -189,6 +183,9 @@ class Database:
         with open(os.path.join(self.__private_folder, 'all_comments.json'), 'w', encoding='utf8') as f:
             f.write(json.dumps(resolved_comments, default=serialize, indent=2))
 
+        with open(os.path.join(self.__private_folder, 'symbol_index.json'), 'w', encoding='utf8') as f:
+            f.write(json.dumps(list(self.__symbols.keys()), default=serialize, indent=2))
+
     def __get_aliases(self, name):
         return self.__aliases[name]
 
@@ -198,3 +195,6 @@ class Database:
         Banana banana
         """
         return self.__symbols.get(name)
+
+    def get_all_symbols(self):
+        return self.__symbols
\ No newline at end of file
