@@ -42,6 +42,7 @@ from hotdoc.core.formatter import Formatter
 from hotdoc.core.comment import Comment
 from hotdoc.extensions.gi.gi_extension import WritableFlag, ReadableFlag, \
     ConstructFlag, ConstructOnlyFlag
+from hotdoc.extensions.gi.symbols import GIClassSymbol
 from hotdoc.extensions.devhelp.devhelp_extension import TYPE_MAP
 
 
@@ -51,17 +52,19 @@ Extract gstreamer plugin documentation from sources and
 built plugins.
 """
 
+
 def _inject_fundamentals():
     # Working around https://gitlab.freedesktop.org/gstreamer/gst-plugins-good/-/issues/744
-    CLanguage.add_fundamental("JackClient", Link("https://jackaudio.org/api/jack_8h.html", 'jack_client_t', None))
+    CLanguage.add_fundamental("JackClient", Link("https://jackaudio.org/api/jack_8h.html",
+                                                 'jack_client_t', None))
     CLanguage.add_fundamental(
         "GrapheneMatrix",
         Link("https://developer.gnome.org/graphene/stable/graphene-Matrix.html#graphene-matrix-t",
-                'graphen_matrix_t', 'GrapheneMatrix'))
+             'graphen_matrix_t', 'GrapheneMatrix'))
     CLanguage.add_fundamental(
         "CairoContext",
         Link("https://www.cairographics.org/manual/cairo-cairo-t.html#cairo-t",
-                'cairo_t', 'CairoContext'))
+             'cairo_t', 'CairoContext'))
 
 
 def _cleanup_package_name(package_name):
@@ -72,19 +75,6 @@ def _cleanup_package_name(package_name):
                     'Plug-ins').strip(' ')
 
 
-def create_hierarchy(element_dict):
-
-    hierarchy = []
-
-    for klass_name in element_dict["hierarchy"][1:]:
-        link = Link(None, klass_name, klass_name)
-        sym = QualifiedSymbol(type_tokens=[link])
-        hierarchy.append(sym)
-
-    hierarchy.reverse()
-    return hierarchy
-
-
 def type_tokens_from_type_name(type_name, python_lang):
     res = [Link(None, type_name, type_name, mandatory=True)]
     if python_lang and not python_lang.get_fundamental(type_name):
@@ -137,23 +127,34 @@ class GstPluginsSymbol(Symbol):
         return sorted(all_elements, key=lambda x: x.display_name)
 
     def get_children_symbols(self):
-        return self.plugins
+        return list(self.plugins) + super().get_children_symbols()
 
     @classmethod
     def get_plural_name(cls):
         return ""
 
 
-class GstElementSymbol(ClassSymbol):
+class GstElementSymbol(GIClassSymbol):
     TEMPLATE = """
-        @require(symbol, hierarchy, desc)
+        @require(symbol, hierarchy, desc, interfaces)
         @desc
 
         @if hierarchy:
         <h2>Hierarchy</h2>
-        <div class="hierarchy_container">
-            @hierarchy
-        </div>
+            <div class="hierarchy_container">
+                @hierarchy
+            </div>
+        @end
+        @if interfaces:
+            <h2>Implemented interfaces</h2>
+            <div>
+                <pre>
+                @for interface in interfaces:
+@interface
+ \
+@end
+</pre>
+            </div>
         @end
         <h2 class="symbol_section">Factory details</h2>
         <div class="symbol-detail">
@@ -172,7 +173,7 @@ class GstElementSymbol(ClassSymbol):
         self.rank = None
         self.author = None
         self.plugin = None
-        ClassSymbol.__init__(self, **kwargs)
+        super().__init__(**kwargs)
 
     @classmethod
     def get_plural_name(cls):
@@ -220,7 +221,7 @@ class GstPluginSymbol(Symbol):
         Symbol.__init__(self, **kwargs)
 
     def get_children_symbols(self):
-        return self.elements
+        return self.elements + super().get_children_symbols()
 
     @classmethod
     def get_plural_name(cls):
@@ -247,7 +248,7 @@ class GstNamedConstantsSymbols(Symbol):
         Symbol.__init__(self, **kwargs)
 
     def get_children_symbols(self):
-        return self.members
+        return self.members + super().get_children_symbols()
 
     def get_extra_links(self):
         return [m.link for m in self.members]
@@ -295,7 +296,7 @@ class GstPadTemplateSymbol(Symbol):
         Symbol.__init__(self, **kwargs)
 
     def get_children_symbols(self):
-        return [self.qtype, self.object_type]
+        return [self.qtype, self.object_type] + super().get_children_symbols()
 
     # pylint: disable=no-self-use
     def get_type_name(self):
@@ -431,7 +432,10 @@ class GstFormatter(Formatter):
         hierarchy = self._format_hierarchy(symbol)
 
         template = self.engine.get_template('element.html')
-        return template.render({'symbol': symbol, 'hierarchy': hierarchy, 'desc': ''})
+        interfaces = []
+        for interface in symbol.interfaces:
+            interfaces.append(self._format_linked_symbol(interface))
+        return template.render({'symbol': symbol, 'hierarchy': hierarchy, 'desc': '', 'interfaces': interfaces})
 
     def _format_name_constant_value(self, symbol):
         template = self.engine.get_template('enumtemplate.html')
@@ -839,6 +843,17 @@ class GstExtension(Extension):
         symbol.values = enum
         return symbol
 
+    def __create_hierarchy(self, pagename, element_dict):
+        hierarchy = []
+        for klass_name in element_dict["hierarchy"][1:]:
+            self._remember_symbol_type(klass_name, pagename)
+            link = Link(None, klass_name, klass_name, mandatory=True)
+            sym = QualifiedSymbol(type_tokens=[link])
+            hierarchy.append(sym)
+
+        hierarchy.reverse()
+        return hierarchy
+
     def __create_object_type(self, pagename, _object):
         unique_name = _object['hierarchy'][0]
         self.__create_property_symbols(
@@ -848,7 +863,7 @@ class GstExtension(Extension):
 
         return self.create_symbol(
             ClassSymbol,
-            hierarchy=create_hierarchy(_object),
+            hierarchy=self.__create_hierarchy(pagename, _object),
             display_name=unique_name,
             unique_name=unique_name,
             parent_name=unique_name,
@@ -933,20 +948,24 @@ class GstExtension(Extension):
         for ename, element in plugin.get('elements', {}).items():
             element['name'] = ename
             pagename, _ = self.__extract_feature_comment("element", element)
+            interfaces = []
+            for interface in element.get("interfaces", []):
+                interfaces.append(QualifiedSymbol(type_tokens=[Link(None, interface, interface, mandatory=True)]))
 
             aliases = self._get_aliases([pagename, element['hierarchy'][0]])
             sym = self.create_symbol(
                 GstElementSymbol,
                 parent_name=None,
                 display_name=element['name'],
-                hierarchy=create_hierarchy(element),
+                hierarchy=self.__create_hierarchy(pagename, element),
                 unique_name=element['name'],
                 filename=plugin_name,
                 extra={'gst-element-name': pagename},
                 rank=str(element['rank']), author=element['author'],
                 classification=element['klass'], plugin=plugin['filename'],
                 aliases=aliases,
-                package=plugin['package'])
+                package=plugin['package'],
+                interfaces=interfaces)
 
             if not sym:
                 continue
